@@ -17,13 +17,14 @@
 
 from __future__ import absolute_import
 
+import logging
+
+from . import fresh_operation
 from .models.folder import Folder
 from .models.sheet import Sheet
-import logging
-from . import fresh_operation
 
 
-class Home(object):
+class Home:
 
     """Class for handling Home operations."""
 
@@ -42,16 +43,14 @@ class Home(object):
             Result
         """
         if isinstance(folder_obj, str):
-            folder_obj = Folder({
-                'name': folder_obj
-            })
+            folder_obj = Folder({"name": folder_obj})
 
-        _op = fresh_operation('create_folder')
-        _op['method'] = 'POST'
-        _op['path'] = '/home/folders'
-        _op['json'] = folder_obj
+        _op = fresh_operation("create_folder")
+        _op["method"] = "POST"
+        _op["path"] = "/home/folders"
+        _op["json"] = folder_obj
 
-        expected = ['Result', 'Folder']
+        expected = ["Result", "Folder"]
 
         prepped_request = self._base.prepare_request(_op)
         response = self._base.request(prepped_request, expected, _op)
@@ -71,12 +70,12 @@ class Home(object):
         if isinstance(sheet_obj, dict):
             sheet_obj = Sheet(sheet_obj)
 
-        _op = fresh_operation('create_sheet')
-        _op['method'] = 'POST'
-        _op['path'] = '/sheets'
-        _op['json'] = sheet_obj
+        _op = fresh_operation("create_sheet")
+        _op["method"] = "POST"
+        _op["path"] = "/sheets"
+        _op["json"] = sheet_obj
 
-        expected = ['Result', 'Sheet']
+        expected = ["Result", "Sheet"]
 
         prepped_request = self._base.prepare_request(_op)
         response = self._base.request(prepped_request, expected, _op)
@@ -101,25 +100,25 @@ class Home(object):
             sheet_obj (Sheet): Sheet object.
             include (list[str]): A list of optional elements
                 to include from the source Template. Valid list values:
-                data, attachments, discussions, cellLinks, forms.
+                attachments, cellLinks, data, discussions, forms, rules and ruleRecipients.
 
         Returns:
             Result
         """
-        _op = fresh_operation('create_sheet_from_template')
-        _op['method'] = 'POST'
-        _op['path'] = '/sheets'
-        _op['query_params']['include'] = include
-        _op['json'] = sheet_obj
+        _op = fresh_operation("create_sheet_from_template")
+        _op["method"] = "POST"
+        _op["path"] = "/sheets"
+        _op["query_params"]["include"] = include
+        _op["json"] = sheet_obj
 
-        expected = ['Result', 'Sheet']
+        expected = ["Result", "Sheet"]
 
         prepped_request = self._base.prepare_request(_op)
         response = self._base.request(prepped_request, expected, _op)
 
         return response
 
-    def list_all_contents(self, include=None):
+    def list_all_contents(self, include=None, exclude=None):
         """Get a nested list of all Home objects, including Sheets,
         Workspaces, Folders, Reports and Templates.
 
@@ -127,16 +126,20 @@ class Home(object):
             include (list[str]): A comma-separated list of
                 optional elements to include in the response. Valid list
                 values: ownerInfo, sheetVersion, source.
+            include (list[str]): A comma-separated list of
+                optional elements to exclude from the response. Valid list
+                values: permalinks.
 
         Returns:
             Home
         """
-        _op = fresh_operation('list_all_contents')
-        _op['method'] = 'GET'
-        _op['path'] = '/home'
-        _op['query_params']['include'] = include
+        _op = fresh_operation("list_all_contents")
+        _op["method"] = "GET"
+        _op["path"] = "/home"
+        _op["query_params"]["include"] = include
+        _op["query_params"]["exclude"] = exclude
 
-        expected = 'Home'
+        expected = "Home"
         prepped_request = self._base.prepare_request(_op)
         response = self._base.request(prepped_request, expected, _op)
 
@@ -156,14 +159,14 @@ class Home(object):
         Returns:
             IndexResult
         """
-        _op = fresh_operation('list_folders')
-        _op['method'] = 'GET'
-        _op['path'] = '/home/folders'
-        _op['query_params']['pageSize'] = page_size
-        _op['query_params']['page'] = page
-        _op['query_params']['includeAll'] = include_all
+        _op = fresh_operation("list_folders")
+        _op["method"] = "GET"
+        _op["path"] = "/home/folders"
+        _op["query_params"]["pageSize"] = page_size
+        _op["query_params"]["page"] = page
+        _op["query_params"]["includeAll"] = include_all
 
-        expected = ['IndexResult', 'Folder']
+        expected = ["IndexResult", "Folder"]
 
         prepped_request = self._base.prepare_request(_op)
         response = self._base.request(prepped_request, expected, _op)
